==> igniteui-react-layouts-18.1.0.tgz: package/esm2015/lib/ToolbarView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType, INotifyPropertyChanged_$type, PropertyChangedEventArgs, runOn, delegateCombine, enumGetBox, typeCast, delegateRemove, fromEn } from "igniteui-react-core";
import { RenderingContext } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ToolPanel } from "./ToolPanel";
import { DOMExecutionContext } from "igniteui-react-core";
import { CanvasViewRenderer } from "igniteui-react-core";
import { Size } from "igniteui-react-core";
import { NativeUI } from "igniteui-react-core";
import { FontUtil } from "igniteui-react-core";
import { SRProvider } from "igniteui-react-core";
import { ToolActionCollection } from "./ToolActionCollection";
import { ToolbarOrientation_$type } from "./ToolbarOrientation";
import { ToolbarIconManager } from "./ToolbarIconManager";
import { ToolAction } from "./ToolAction";
import { NativeUIInputsFactory } from "igniteui-react-core";
import { BrushUtil } from "igniteui-react-core";
/**
 * @hidden
 */
export let ToolbarView = /*@__PURE__*/ (() => {
    class ToolbarView extends Base {
        constructor() {
            super();
            this.n = null;
            this.m = null;
            this.a = null;
            this.i = null;
            this.l = null;
            this.e = null;
            this.k = null;
            this.b = ((() => {
                let $ret = new FontInfo();
                $ret.n = "Verdana";
                $ret.d = 13;
                $ret.q = "Normal";
                $ret.s = "Normal";
                $ret.o = "Normal";
                return $ret;
            })());
            this.aa = new Size();
            this.c = null;
            this._gridExternal = null;
            this.f = false;
            this.j = null;
        }
        p() {
            return this.i;
        }
        v() {
        }
        t(a) {
            if (a == null) {
                this.i = null;
                return;
            }
            this.a.a = new DOMExecutionContext(a);
            this.i = a;
            this.l = this.i.createElement("canvas");
            this.e = new RenderingContext(new CanvasViewRenderer(), this.i.get2DCanvasContext(this.l));
            this.k = this.i.createElement("div");
            this.y();
            let b = new ToolPanel();
            let c = this.i.createElement("div");
            c.setStyleProperty("width", "100%");
            c.setStyleProperty("height", "100%");
            this.i.append(c);
            let d = this.i.getSubRenderer(c);
            b.provideContainer(d);
            let e = this.i.getExternal(b, this.i.rootWrapper, this.i.getExternal(this.a, null, null));
            this.a.am(b);
            let f = Math.round(a.rootWrapper.width());
            let g = Math.round(a.rootWrapper.height());
            this.i.rootWrapper.setStyleProperty("position", "relative");
        }
        y() {
        }
        x() {
            if (this.i != null) {
            }
        }
        s() {
            if (this.i == null) {
                return;
            }
            let a = this.i.rootWrapper.width();
            let b = this.i.rootWrapper.height();
            this.aa = new Size(1, a, b);
        }
        z() {
            let a = this.i;
            if (null == a) {
                return;
            }
            let b = a.rootWrapper;
            if (null != b) {
                NativeUI.o(b, this.a.a1);
                NativeUI.k(b, this.a.ay);
            }
        }
        d() {
            return this.b;
        }
        u() {
        }
        w() {
        }
        r() {
        }
        g() {
            return this.aa.width;
        }
        h(a) {
            this.c = this.a.p();
            return FontUtil.measureStringWidth(a, this.c, this.e);
        }
        q(a, b) {
            if (this.j == null) {
                this.j = this.i.createElement("div");
            }
            b(this.j.getNativeElement());
        }
    }
    ToolbarView.$t = /*@__PURE__*/ markType(ToolbarView, 'ToolbarView');
    return ToolbarView;
})();
/**
 * @hidden
 */
export let Toolbar = /*@__PURE__*/ (() => {
    class Toolbar extends Base {
        constructor() {
            super();
            this.k = null;
            this.s = false;
            this.q = null;
            this.l = null;
            this.d = new ToolActionCollection();
            this.b = new ToolActionCollection();
            this.c = new ToolActionCollection();
            this.h = Toolbar.i;
            this.m = null;
            this.u = Toolbar.v;
            this.aw = Toolbar.az;
            this.ax = Toolbar.a0;
            this.n = null;
            this.t = false;
            this.propertyChanged = null;
            this.a = null;
            ToolbarIconManager.c();
            let a = this.actions;
            a.collectionChanged = delegateCombine(a.collectionChanged, runOn(this, this.ah));
            NativeUIInputsFactory.m();
            let b = new ToolbarView();
            b.a = this;
            this.k = b;
            this.k.v();
        }
        get r() {
            if (this.q == null) {
                this.q = new SRProvider(this.k.i);
                this.q.cb("Layouts");
            }
            return this.q;
        }
        am(a) {
            this.l = a;
            let b = this.l;
            b.onCommand = delegateCombine(b.onCommand, runOn(this, this.ag));
            this.l.k = this.j;
        }
        ag(a, b) {
            if (this.m != null) {
                this.m.onToolCommandExecuting(b.a);
            }
        }
        ap(a) {
        }
        get autoGeneratedActions() {
            return this.d;
        }
        set autoGeneratedActions(a) {
            let b = this.d;
            this.d = a;
            if (b != this.d) {
                this.aq("AutoGeneratedActions", b, this.d);
            }
        }
        get actions() {
            return this.b;
        }
        set actions(a) {
            let b = this.b;
            this.b = a;
            if (b != this.b) {
                this.aq("Actions", b, this.b);
            }
        }
        get actualActions() {
            return this.c;
        }
        set actualActions(a) {
            let b = this.c;
            this.c = a;
            if (b != this.c) {
                this.aq("ActualActions", b, this.c);
            }
        }
        get j() {
            return this.h;
        }
        set j(a) {
            let b = this.h;
            this.h = a;
            if (b != this.h) {
                this.aq("Orientation", enumGetBox(ToolbarOrientation_$type, b), enumGetBox(ToolbarOrientation_$type, a));
            }
        }
        get w() {
            return this.u;
        }
        set w(a) {
            let b = this.u;
            this.u = a;
            if (b != this.u) {
                this.aq("Target", b, a);
            }
        }
        get ay() {
            return this.aw;
        }
        set ay(a) {
            let b = this.aw;
            this.aw = a;
            if (b != this.aw) {
                this.aq("BackgroundColor", b, a);
            }
        }
        get a1() {
            return this.ax;
        }
        set a1(a) {
            let b = this.ax;
            this.ax = a;
            if (b != this.ax) {
                this.aq("TextColor", b, a);
            }
        }
        get o() {
            return this.n;
        }
        set o(a) {
            let b = this.n;
            this.n = a;
            if (b != this.n) {
                this.aq("CellTextStyle", b, this.n);
            }
        }
        p() {
            if (this.o == null) {
                return this.k.d();
            }
            return this.o;
        }
        ah(a, b) {
            if (b.oldItems != null) {
                for (let c of fromEn(b.oldItems)) {
                    if (typeCast(INotifyPropertyChanged_$type, c) !== null) {
                        let d = c;
                        d.propertyChanged = delegateRemove(d.propertyChanged, runOn(this, this.ai));
                    }
                }
            }
            if (b.newItems != null) {
                for (let e of fromEn(b.newItems)) {
                    if (typeCast(INotifyPropertyChanged_$type, e) !== null) {
                        let f = e;
                        f.propertyChanged = delegateCombine(f.propertyChanged, runOn(this, this.ai));
                    }
                }
            }
            this.ao();
        }
        ai(a, b) {
            this.ao();
        }
        ao() {
            this.au();
        }
        au() {
            if (this.t) {
                return;
            }
            this.t = true;
            this.a.enqueueAction(runOn(this, this.ak));
        }
        ak() {
            if (!this.t) {
                return;
            }
            this.t = false;
            this.av();
            if (this.l.actions != this.actualActions) {
                this.l.actions = this.actualActions;
            }
        }
        av() {
            this.actualActions.clear();
            for (let a = 0; a < this.actions.count; a++) {
                this.actualActions.add(this.actions._inner[a]);
            }
            for (let b = 0; b < this.autoGeneratedActions.count; b++) {
                this.actualActions.add(this.autoGeneratedActions._inner[b]);
            }
        }
        al() {
            if (this.t) {
                this.ak();
            }
        }
        notifySizeChanged() {
            this.k.s();
        }
        destroy() {
            this.provideContainer(null);
        }
        provideContainer(a) {
            this.k.t(a);
        }
        aq(a, b, c) {
            if (this.propertyChanged != null) {
                this.propertyChanged(this, new PropertyChangedEventArgs(a));
            }
            this.as(a, b, c);
        }
        as(a, b, c) {
            switch (a) {
                case "CellTextStyle":
                    this.au();
                    break;
                case "BackgroundColor":
                case "TextColor":
                    this.au();
                    break;
                case "Orientation":
                    if (this.l != null) {
                        this.l.k = this.j;
                    }
                    break;
                case "Target":
                    let d = c;
                    let e = b;
                    this.ar(e, d);
                    break;
            }
        }
        ar(a, b) {
            this.m = b;
            if (a != null) {
                this.autoGeneratedActions.clear();
                this.au();
            }
            if (b != null) {
                this.autoGeneratedActions.clear();
                let c = b.getDesiredToolbarActions();
                if (c != null) {
                    for (let d = 0; d < c.length; d++) {
                        let e = ToolAction.a(c[d]);
                        this.autoGeneratedActions.add(e);
                    }
                }
                this.au();
            }
        }
    }
    Toolbar.$t = /*@__PURE__*/ markType(Toolbar, 'Toolbar', Base.$, [INotifyPropertyChanged_$type]);
    Toolbar.i = 1;
    Toolbar.v = null;
    Toolbar.az = /*@__PURE__*/ BrushUtil.g(255, 248, 248, 248);
    Toolbar.a0 = /*@__PURE__*/ BrushUtil.g(255, 24, 29, 31);
    return Toolbar;
})();

==> igniteui-react-layouts-18.1.3.tgz: package/esm2015/lib/ToolbarView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType, INotifyPropertyChanged_$type, PropertyChangedEventArgs, runOn, delegateCombine, enumGetBox, typeCast, delegateRemove, fromEn } from "igniteui-react-core";
import { RenderingContext } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ToolPanel } from "./ToolPanel";
import { DOMExecutionContext } from "igniteui-react-core";
import { CanvasViewRenderer } from "igniteui-react-core";
import { Size } from "igniteui-react-core";
import { NativeUI } from "igniteui-react-core";
import { FontUtil } from "igniteui-react-core";
import { SRProvider } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { ToolActionCollection } from "./ToolActionCollection";
import { ToolbarOrientation_$type } from "./ToolbarOrientation";
import { ToolbarIconManager } from "./ToolbarIconManager";
import { ToolAction } from "./ToolAction";
import { NativeUIInputsFactory } from "igniteui-react-core";
import { NativeUIXInputsFactory } from "igniteui-react-inputs";
import { BrushUtil } from "igniteui-react-core";
/**
 * @hidden
 */
export let ToolbarView = /*@__PURE__*/ (() => {
    class ToolbarView extends Base {
        constructor() {
            super();
            this.n = null;
            this.m = null;
            this.a = null;
            this.i = null;
            this.l = null;
            this.e = null;
            this.k = null;
            this.b = ((() => {
                let $ret = new FontInfo();
                $ret.n = "Verdana";
                $ret.d = 13;
                $ret.q = "Normal";
                $ret.s = "Normal";
                $ret.o = "Normal";
                return $ret;
            })());
            this.aa = new Size();
            this.c = null;
            this._gridExternal = null;
            this.f = false;
            this.j = null;
        }
        p() {
            return this.i;
        }
        v() {
        }
        t(a) {
            if (a == null) {
                this.i = null;
                return;
            }
            this.a.a = new DOMExecutionContext(a);
            this.i = a;
            this.l = this.i.createElement("canvas");
            this.e = new RenderingContext(new CanvasViewRenderer(), this.i.get2DCanvasContext(this.l));
            this.k = this.i.createElement("div");
            this.y();
            let b = new ToolPanel();
            let c = this.i.createElement("div");
            c.setStyleProperty("width", "100%");
            c.setStyleProperty("height", "100%");
            this.i.append(c);
            let d = this.i.getSubRenderer(c);
            b.provideContainer(d);
            let e = this.i.getExternal(b, this.i.rootWrapper, this.i.getExternal(this.a, null, null));
            this.a.aq(b);
            let f = Math.round(a.rootWrapper.width());
            let g = Math.round(a.rootWrapper.height());
            this.i.rootWrapper.setStyleProperty("position", "relative");
        }
        y() {
        }
        x() {
            if (this.i != null) {
            }
        }
        s() {
            if (this.i == null) {
                return;
            }
            let a = this.i.rootWrapper.width();
            let b = this.i.rootWrapper.height();
            this.aa = new Size(1, a, b);
            this.a.at(this.aa);
        }
        z() {
            let a = this.i;
            if (null == a) {
                return;
            }
            let b = a.rootWrapper;
            if (null != b) {
                NativeUI.o(b, this.a.a6);
                NativeUI.k(b, this.a.a3);
            }
        }
        d() {
            return this.b;
        }
        u() {
        }
        w() {
        }
        r() {
        }
        g() {
            return this.aa.width;
        }
        h(a) {
            this.c = this.a.r();
            return FontUtil.measureStringWidth(a, this.c, this.e);
        }
        q(a, b) {
            if (this.j == null) {
                this.j = this.i.createElement("div");
            }
            b(this.j.getNativeElement());
        }
    }
    ToolbarView.$t = /*@__PURE__*/ markType(ToolbarView, 'ToolbarView');
    return ToolbarView;
})();
/**
 * @hidden
 */
export let Toolbar = /*@__PURE__*/ (() => {
    class Toolbar extends Base {
        constructor() {
            super();
            this.k = null;
            this.u = false;
            this.s = null;
            this.l = null;
            this.m = 0;
            this.d = new ToolActionCollection();
            this.b = new ToolActionCollection();
            this.c = new ToolActionCollection();
            this.h = Toolbar.i;
            this.o = null;
            this.w = Toolbar.x;
            this.a1 = Toolbar.a4;
            this.a2 = Toolbar.a5;
            this.p = null;
            this.v = false;
            this.propertyChanged = null;
            this.a = null;
            ToolbarIconManager.c();
            let a = this.actions;
            a.collectionChanged = delegateCombine(a.collectionChanged, runOn(this, this.ak));
            let b = this.actualActions;
            b.collectionChanged = delegateCombine(b.collectionChanged, runOn(this, this.am));
            NativeUIInputsFactory.n();
            NativeUIXInputsFactory.h();
            let c = new ToolbarView();
            c.a = this;
            this.k = c;
            this.k.v();
        }
        get t() {
            if (this.s == null) {
                this.s = new SRProvider(this.k.i);
                this.s.cb("Layouts");
            }
            return this.s;
        }
        aq(a) {
            this.l = a;
            this.l.n = this.m;
            let b = this.l;
            b.onCommand = delegateCombine(b.onCommand, runOn(this, this.aj));
            this.l.k = this.j;
        }
        aj(a, b) {
            if (this.o != null) {
                this.o.onToolCommandExecuting(b.a);
            }
        }
        at(a) {
            this.l.notifySizeChanged();
        }
        get n() {
            return this.m;
        }
        set n(a) {
            let b = this.m;
            this.m = a;
            if (b != this.m) {
                this.au("BaseTheme", enumGetBox(BaseControlTheme_$type, b), enumGetBox(BaseControlTheme_$type, a));
            }
        }
        get autoGeneratedActions() {
            return this.d;
        }
        set autoGeneratedActions(a) {
            let b = this.d;
            this.d = a;
            if (b != this.d) {
                this.au("AutoGeneratedActions", b, this.d);
            }
        }
        get actions() {
            return this.b;
        }
        set actions(a) {
            let b = this.b;
            this.b = a;
            if (b != this.b) {
                this.au("Actions", b, this.b);
            }
        }
        get actualActions() {
            return this.c;
        }
        set actualActions(a) {
            let b = this.c;
            this.c = a;
            if (b != this.c) {
                this.au("ActualActions", b, this.c);
            }
        }
        get j() {
            return this.h;
        }
        set j(a) {
            let b = this.h;
            this.h = a;
            if (b != this.h) {
                this.au("Orientation", enumGetBox(ToolbarOrientation_$type, b), enumGetBox(ToolbarOrientation_$type, a));
            }
        }
        get y() {
            return this.w;
        }
        set y(a) {
            let b = this.w;
            this.w = a;
            if (b != this.w) {
                this.au("Target", b, a);
            }
        }
        get a3() {
            return this.a1;
        }
        set a3(a) {
            let b = this.a1;
            this.a1 = a;
            if (b != this.a1) {
                this.au("BackgroundColor", b, a);
            }
        }
        get a6() {
            return this.a2;
        }
        set a6(a) {
            let b = this.a2;
            this.a2 = a;
            if (b != this.a2) {
                this.au("TextColor", b, a);
            }
        }
        get q() {
            return this.p;
        }
        set q(a) {
            let b = this.p;
            this.p = a;
            if (b != this.p) {
                this.au("CellTextStyle", b, this.p);
            }
        }
        r() {
            if (this.q == null) {
                return this.k.d();
            }
            return this.q;
        }
        ak(a, b) {
            if (b.oldItems != null) {
                for (let c of fromEn(b.oldItems)) {
                    if (typeCast(INotifyPropertyChanged_$type, c) !== null) {
                        let d = c;
                        d.propertyChanged = delegateRemove(d.propertyChanged, runOn(this, this.al));
                    }
                }
            }
            if (b.newItems != null) {
                for (let e of fromEn(b.newItems)) {
                    if (typeCast(INotifyPropertyChanged_$type, e) !== null) {
                        let f = e;
                        f.propertyChanged = delegateCombine(f.propertyChanged, runOn(this, this.al));
                    }
                }
            }
            this.as();
        }
        am(a, b) {
            this.a0();
        }
        a0() {
            for (let a = 0; a < this.actualActions.count; a++) {
                this.actualActions._inner[a].g = this.n;
            }
        }
        al(a, b) {
            this.as();
        }
        as() {
            this.ay();
        }
        ay() {
            if (this.v) {
                return;
            }
            this.v = true;
            this.a.enqueueAction(runOn(this, this.ao));
        }
        ao() {
            if (!this.v) {
                return;
            }
            this.v = false;
            this.az();
            if (this.l.actions != this.actualActions) {
                this.l.actions = this.actualActions;
            }
        }
        az() {
            this.actualActions.clear();
            for (let a = 0; a < this.actions.count; a++) {
                this.actualActions.add(this.actions._inner[a]);
            }
            for (let b = 0; b < this.autoGeneratedActions.count; b++) {
                this.actualActions.add(this.autoGeneratedActions._inner[b]);
            }
        }
        ap() {
            if (this.v) {
                this.ao();
            }
        }
        notifySizeChanged() {
            this.k.s();
        }
        destroy() {
            this.provideContainer(null);
        }
        provideContainer(a) {
            this.k.t(a);
        }
        au(a, b, c) {
            if (this.propertyChanged != null) {
                this.propertyChanged(this, new PropertyChangedEventArgs(a));
            }
            this.aw(a, b, c);
        }
        aw(a, b, c) {
            switch (a) {
                case "CellTextStyle":
                    this.ay();
                    break;
                case "BackgroundColor":
                case "TextColor":
                    this.ay();
                    break;
                case "Orientation":
                    if (this.l != null) {
                        this.l.k = this.j;
                    }
                    break;
                case "Target":
                    let d = c;
                    let e = b;
                    this.av(e, d);
                    break;
            }
        }
        av(a, b) {
            this.o = b;
            if (a != null) {
                this.autoGeneratedActions.clear();
                this.ay();
            }
            if (b != null) {
                this.autoGeneratedActions.clear();
                let c = b.getDesiredToolbarActions();
                if (c != null) {
                    for (let d = 0; d < c.length; d++) {
                        let e = ToolAction.a(c[d]);
                        this.autoGeneratedActions.add(e);
                    }
                }
                this.ay();
            }
        }
    }
    Toolbar.$t = /*@__PURE__*/ markType(Toolbar, 'Toolbar', Base.$, [INotifyPropertyChanged_$type]);
    Toolbar.i = 1;
    Toolbar.x = null;
    Toolbar.a4 = /*@__PURE__*/ BrushUtil.g(255, 248, 248, 248);
    Toolbar.a5 = /*@__PURE__*/ BrushUtil.g(255, 24, 29, 31);
    return Toolbar;
})();
